@@ -1,2 +1,5 @@
-__version__ = "2.4.2"
+"""
+Info script
+"""
+__version__ = "2.5.1"
 __homepage__ = "https://github.com/jackd248/db-sync-tool"
