@@ -1,11 +1,16 @@
 #!/usr/bin/env python3
 # -*- coding: future_fstrings -*-
 
+"""
+System module
+"""
+
 import sys
 import json
 import os
 import getpass
-from db_sync_tool.utility import log, parser, mode, helper, output
+import yaml
+from db_sync_tool.utility import log, parser, mode, helper, output, validation
 
 #
 # GLOBALS
@@ -28,14 +33,16 @@ config = {
     'ssh_password': {
         'origin': None,
         'target': None
-    }
+    },
+    'link_target': None,
+    'link_origin': None,
 }
 
 #
 # DEFAULTS
 #
 
-default_local_sync_path = '/tmp/'
+default_local_sync_path = '/tmp/db_sync_tool/'
 
 
 #
@@ -74,10 +81,23 @@ def get_configuration(host_config):
     if not _config_file_path is None:
         if os.path.isfile(_config_file_path):
             with open(_config_file_path, 'r') as read_file:
-                config.update(json.load(read_file))
+                if _config_file_path.endswith('.json'):
+                    config.update(json.load(read_file))
+                elif _config_file_path.endswith('.yaml') or _config_file_path.endswith('.yml'):
+                    config.update(yaml.safe_load(read_file))
+                else:
+                    sys.exit(
+                        output.message(
+                            output.Subject.ERROR,
+                            f'Unsupported configuration file type [json,yml,yaml]: '
+                            f'{config["config_file_path"]}',
+                            False
+                        )
+                    )
                 output.message(
                     output.Subject.LOCAL,
-                    f'Loading host configuration {output.CliFormat.BLACK}{_config_file_path}{output.CliFormat.ENDC}',
+                    f'Loading host configuration '
+                    f'{output.CliFormat.BLACK}{_config_file_path}{output.CliFormat.ENDC}',
                     True
                 )
         else:
@@ -89,6 +109,7 @@ def get_configuration(host_config):
                 )
             )
 
+    validation.check(config)
     check_options()
     helper.run_script(script='before')
     log.get_logger().info('Starting db_sync_tool')
@@ -131,9 +152,12 @@ def check_authorization(client):
     # only need authorization if client is remote
     if mode.is_remote(client):
         # Workaround if no authorization is needed
-        if (mode.get_sync_mode() == mode.SyncMode.DUMP_REMOTE and client == mode.Client.TARGET) or (
-                mode.get_sync_mode() == mode.SyncMode.DUMP_LOCAL and client == mode.Client.ORIGIN) or (
-                mode.get_sync_mode() == mode.SyncMode.IMPORT_REMOTE and client == mode.Client.ORIGIN):
+        if (mode.get_sync_mode() == mode.SyncMode.DUMP_REMOTE and
+            client == mode.Client.TARGET) or \
+                (mode.get_sync_mode() == mode.SyncMode.DUMP_LOCAL and
+                 client == mode.Client.ORIGIN) or \
+                (mode.get_sync_mode() == mode.SyncMode.IMPORT_REMOTE and
+                 client == mode.Client.ORIGIN):
             return
 
         # ssh key authorization
@@ -153,7 +177,9 @@ def check_authorization(client):
             # user input authorization
             config[client]['password'] = get_password_by_user(client)
 
-        if mode.get_sync_mode() == mode.SyncMode.DUMP_REMOTE and client == mode.Client.ORIGIN and 'password' in config[mode.Client.ORIGIN]:
+        if mode.get_sync_mode() == mode.SyncMode.DUMP_REMOTE and \
+                client == mode.Client.ORIGIN and 'password' in \
+                config[mode.Client.ORIGIN]:
             config[mode.Client.TARGET]['password'] = config[mode.Client.ORIGIN]['password']
 
 
@@ -268,6 +294,7 @@ def check_args_options(config_file=None,
 def link_configuration_with_hosts():
     """
     Merging the hosts definition with the given configuration file
+    @ToDo Simplify function
     :return:
     """
     if ('link' in config['origin'] or 'link' in config['target']) and config['link_hosts'] == '':
@@ -276,7 +303,8 @@ def link_configuration_with_hosts():
             output.message(
                 output.Subject.ERROR,
                 f'Missing hosts file for linking hosts with configuration. '
-                f'Use the "-o" / "--hosts" argument to define the filepath for the hosts file, when using a link parameter within the configuration.',
+                f'Use the "-o" / "--hosts" argument to define the filepath for the hosts file, '
+                f'when using a link parameter within the configuration.',
                 False
             )
         )
@@ -290,15 +318,38 @@ def link_configuration_with_hosts():
                     f'Linking configuration with hosts {output.CliFormat.BLACK}{config["link_hosts"]}{output.CliFormat.ENDC}',
                     True
                 )
-                if 'link' in config['origin']:
-                    _host_name = str(config['origin']['link']).replace('@','')
-                    if _host_name in _hosts:
-                        config['origin'] = {**config['origin'], **_hosts[_host_name]}
+                if not config['config_file_path'] is None:
+                    if 'link' in config['origin']:
+                        _host_name = str(config['origin']['link']).replace('@', '')
+                        if _host_name in _hosts:
+                            config['origin'] = {**config['origin'], **_hosts[_host_name]}
 
-                if 'link' in config['target']:
-                    _host_name = str(config['target']['link']).replace('@','')
-                    if _host_name in _hosts:
-                        config['target'] = {**config['target'], **_hosts[_host_name]}
+                    if 'link' in config['target']:
+                        _host_name = str(config['target']['link']).replace('@', '')
+                        if _host_name in _hosts:
+                            config['target'] = {**config['target'], **_hosts[_host_name]}
+                else:
+                    if 'link_target' in config and 'link_origin' in config:
+                        if config['link_target'] in _hosts and config['link_origin'] in _hosts:
+                            config['target'] = _hosts[config['link_target']]
+                            config['origin'] = _hosts[config['link_origin']]
+                        else:
+                            sys.exit(
+                                output.message(
+                                    output.Subject.ERROR,
+                                    f'Misconfiguration of link hosts {config["link_origin"]}, '
+                                    f'{config["link_target"]} in {config["link_hosts"]}',
+                                    False
+                                )
+                            )
+                    else:
+                        sys.exit(
+                            output.message(
+                                output.Subject.ERROR,
+                                f'Missing link hosts for {config["link_hosts"]}',
+                                False
+                            )
+                        )
         else:
             sys.exit(
                 output.message(
@@ -307,6 +358,3 @@ def link_configuration_with_hosts():
                     False
                 )
             )
-
-
-
